@@ -83,13 +83,13 @@
 #' complete_params %>% dplyr::filter(parameter == "rbf_sigma") %>% pull(object)
 #'
 #' @export
-finalize <- function (object, ...) {
+finalize <- function(object, ...) {
   UseMethod("finalize")
 }
 
 #' @export
 #' @rdname finalize
-finalize.list <- function (object, x, force = TRUE, ...) {
+finalize.list <- function(object, x, force = TRUE, ...) {
   map(object, finalize, x, force, ...)
 }
 
@@ -125,7 +125,7 @@ finalize.parameters <- function(object, x, force = TRUE, ...) {
 #' @rdname finalize
 get_p <- function(object, x, log_vals = FALSE, ...) {
   if (!inherits(object, "param"))
-    stop("`object` should be a 'param' object.", call. = FALSE)
+    rlang::abort("`object` should be a 'param' object.")
 
   rngs <- range_get(object, original = FALSE)
   if (!is_unknown(rngs$upper))
@@ -133,8 +133,7 @@ get_p <- function(object, x, log_vals = FALSE, ...) {
 
   x_dims <- dim(x)
   if (is.null(x_dims))
-    stop("Cannot determine number of columns. Is `x` a 2D data object?",
-         .call = TRUE)
+    rlang::abort("Cannot determine number of columns. Is `x` a 2D data object?")
 
   if (log_vals) {
     rngs[2] <- log10(x_dims[2])
@@ -142,6 +141,10 @@ get_p <- function(object, x, log_vals = FALSE, ...) {
     rngs[2] <- x_dims[2]
   }
 
+  if (object$type == "integer" & is.null(object$trans)) {
+    rngs <- as.integer(rngs)
+  }
+
   range_set(object, rngs)
 }
 
@@ -160,8 +163,7 @@ get_n_frac <- function(object, x, log_vals = FALSE, frac = 1/3, ...) {
 
   x_dims <- dim(x)
   if (is.null(x_dims))
-    stop("Cannot determine number of columns. Is `x` a 2D data object?",
-         .call = TRUE)
+    rlang::abort("Cannot determine number of columns. Is `x` a 2D data object?")
 
   n_frac <- floor(x_dims[1]*frac)
 
@@ -170,7 +172,9 @@ get_n_frac <- function(object, x, log_vals = FALSE, frac = 1/3, ...) {
   } else {
     rngs[2] <- n_frac
   }
-
+  if (object$type == "integer" & is.null(object$trans) & !log_vals) {
+    rngs <- as.integer(rngs)
+  }
   range_set(object, rngs)
 }
 
@@ -183,8 +187,7 @@ get_n_frac_range <- function(object, x, log_vals = FALSE, frac = c(1/10, 5/10),
 
   x_dims <- dim(x)
   if (is.null(x_dims))
-    stop("Cannot determine number of columns. Is `x` a 2D data object?",
-         .call = TRUE)
+    rlang::abort("Cannot determine number of columns. Is `x` a 2D data object?")
 
   n_frac <- sort(floor(x_dims[1]*frac))
 
@@ -194,6 +197,10 @@ get_n_frac_range <- function(object, x, log_vals = FALSE, frac = c(1/10, 5/10),
     rngs <- n_frac
   }
 
+  if (object$type == "integer" & is.null(object$trans) & !log_vals) {
+    rngs <- as.integer(rngs)
+  }
+
   range_set(object, rngs)
 }
 
@@ -201,6 +208,7 @@ get_n_frac_range <- function(object, x, log_vals = FALSE, frac = c(1/10, 5/10),
 #' @rdname finalize
 get_n <- function(object, x, log_vals = FALSE, ...) {
   get_n_frac(object, x, log_vals, frac = 1, ...)
+
 }
 
 #' @export
@@ -210,8 +218,7 @@ get_rbf_range <- function(object, x, seed = sample.int(10 ^ 5, 1), ...) {
   suppressPackageStartupMessages(requireNamespace("kernlab", quietly = TRUE))
   x_mat <- as.matrix(x)
   if (!is.numeric(x_mat)) {
-    stop("The matrix version of the initialization data is not numeric.",
-         call. = FALSE)
+    rlang::abort("The matrix version of the initialization data is not numeric.")
   }
   with_seed(seed, rng <- kernlab::sigest(x_mat, ...)[-2])
   rng <- log10(rng)
@@ -227,12 +234,15 @@ get_batch_sizes  <- function(object, x, frac = c(1/10, 1/3), ...) {
 
   x_dims <- dim(x)
   if (is.null(x_dims))
-    stop("Cannot determine number of columns. Is `x` a 2D data object?",
-         .call = TRUE)
+    rlang::abort("Cannot determine number of columns. Is `x` a 2D data object?")
 
   n_frac <- sort(floor(x_dims[1]*frac))
   n_frac <- log2(n_frac)
 
+  if (object$type == "integer" & is.null(object$trans)) {
+    n_frac <- as.integer(n_frac)
+  }
+
   range_set(object, n_frac)
 }
 
